package task1;

public class Hand {

    private static final int MAX_CARDS = 11;

    private Card[] cards;
    private int numCards;

    public Hand() {
        // Maximum size hand set to 11 -- very unlikely to occur!
        cards = new Card[MAX_CARDS];
    }

    // Return a multi-line string representation of the current cards in the hand.
    public String getCards() {
        String s = "";
        for (int i = 0; i < numCards; i++) {
            Card card = cards[i];
            if (card != null) {
                s += card.printCard() + "; ";
            }
        }
        return s;
    }

    // Clear the hand of its current cards.
    public void clear() {
        cards = new Card[MAX_CARDS];
    }

    // Add a card to the hand.
    public void addCard(Card card) {
        if (numCards < MAX_CARDS) {
            cards[numCards++] = card;
        } else {
            System.out.println("Unable to add a card, max number of cards is reached");
        }
    }

    // Add up all the values of the cards based on rank.
    // Find the highest value of hand depending on Ace = 1 or 11 points
    // whichever is to your benefit without going over 21!
    // Also calculate total based on all face cards (Jack, Queen, King) being 10 points.
    // Other cards in deck are based on their face value.
    public int total() {
        int acesCount = 0;
        int total = 0;
        for (int i = 0; i < numCards; i++) {
            Card card = cards[i];
            if (isAce(card)) {
                acesCount++;
            } else {
                total += getCardValue(card);
            }
        }
        total += getAcesValue(acesCount, total);
        return total;
    }

    private boolean isAce(Card card) {
        return card.getRank() == 1;
    }

    private int getCardValue(Card card) {
        int rank = card.getRank();
        switch (rank) {
            case 11 :
            case 12 :
            case 13 : {
                return 10;
            }
            default : return rank;
        }
    }

    private int getAcesValue(int numberOfAces, int currentTotal) {
        if (currentTotal == 0 && numberOfAces == 2) {
            return 21;
        }
        int total = currentTotal + numberOfAces;
        for (int i = 0; i < numberOfAces; i++) {
            if (total + 10 <= 21) {
                total += 10;
            }
        }
        return total - currentTotal;
    }
}
